@@ -353,16 +353,15 @@ DISPLAY_CREATIVES_FORMAT_CHOICES = Choices(
     ) % {'price': 399}),
 )
 
-DISPLAY_AGE_14_19 = 1
-DISPLAY_AGE_20_29 = 2
+DISPLAY_AGE_14_29 = 7
 DISPLAY_AGE_30_39 = 3
 DISPLAY_AGE_40_49 = 4
 DISPLAY_AGE_50_59 = 5
 DISPLAY_AGE_60_PLUS = 6
+
 DISPLAY_AGE_CHOICES = Choices(
-    (DISPLAY_AGE_20_29, '20_29', _('20-29 years')),
+    (DISPLAY_AGE_14_29, '14_29', _('14-29 years')),
     (DISPLAY_AGE_30_39, '30_39', _('30-39 years')),
-    (DISPLAY_AGE_14_19, '14_19', _('14-19 years')),
     (DISPLAY_AGE_40_49, '40_49', _('40-49 years')),
     (DISPLAY_AGE_50_59, '50_59', _('50-59 years')),
     (DISPLAY_AGE_60_PLUS, '60_plus', _('60 years or more')),
@@ -910,51 +909,6 @@ class AccountLocationSerializer(serializers.Serializer):
         return data
 
 
-class OrderLineGoogleAdsBasicSerializer(serializers.Serializer):
-    """
-    detailed specifications and briefing information for a google ads basic product - "google_basic" product subtype
-    """
-
-    """
-    what goals should be reached with the advertisement campaign?
-    e.g. get new customers, spread word about a product, etc.
-    """
-    campaign_goal = serializers.CharField(max_length=200, allow_blank=True, required=False)
-
-    """
-    which cities/regions should the ad be targeted on?
-    """
-    regions = serializers.ListField(child=serializers.CharField(max_length=100, required=True), required=True)
-
-    """
-    the expected impression share when the campaign budget is initially calculated
-    """
-    expected_impression_share = serializers.DecimalField(
-        decimal_places=2, max_digits=5, allow_null=True, required=False)
-
-    """
-    the expected impressions when the campaign budget is initially calculated
-    """
-    expected_impressions = serializers.CharField(max_length=50, allow_blank=True, required=False)
-
-    """
-    customer preferred keywords to be found on with his campaign
-    """
-    keywords = serializers.ListField(child=serializers.CharField(max_length=100, required=True), required=True)
-
-    """
-    list of keywords that resulted in zero search volume on campaign calculation
-    these keywords will not be guaranteed to be included in the campaign
-    """
-    keywords_with_zero_search_volume = serializers.ListField(child=serializers.CharField(max_length=100, required=True),
-                                                             required=True)
-
-    """
-    definition of the target group this google ads campaign should be focused on
-    """
-    target_audience = serializers.CharField(max_length=1000, required=True)
-
-
 class OrderLineGoogleAdsPremiumSerializer(serializers.Serializer):
     """
     detailed specifications and briefing information for a google ads premium product - "adwords" product subtype
@@ -1001,6 +955,11 @@ class OrderLineGoogleAdsPremiumSerializer(serializers.Serializer):
     """
     keywords = serializers.ListField(child=serializers.CharField(max_length=100, required=True), required=True)
 
+    """
+    customer preferred topics (branch_codes) from which the keywords will be used to build his campaigns
+    """
+    branch_codes = serializers.ListField(child=serializers.CharField(max_length=100, required=True), required=False)
+
     """
     list of keywords that resulted in zero search volume on campaign calculation
     these keywords will not be guaranteed to be included in the campaign
@@ -1198,9 +1157,9 @@ class OrderLineDisplayPremiumSerializer(serializers.Serializer):
     creatives_format = serializers.ChoiceField(choices=DISPLAY_CREATIVES_FORMAT_CHOICES, required=True)
 
     """
-    impressions per day, used for fixed runtime premium product
+    Total impressions of whole runtime, used for fixed runtime premium product
     """
-    impressions_per_day = serializers.IntegerField(allow_null=True, required=False)
+    impressions_one_time = serializers.IntegerField(allow_null=True, required=False)
 
     """
     impressions per month, used by basic (20000/40000/80000/etc impressions) or continuous premium product
@@ -1267,6 +1226,16 @@ class OrderLineDisplayPremiumSerializer(serializers.Serializer):
     """
     creative_options = serializers.ChoiceField(choices=CREATIVE_OPTION_CHOICES, required=True)
 
+    def validate(self, data):
+        if data.get('booking_type') == BOOKING_TYPE_FIXED and not data.get('impressions_one_time'):
+            raise serializers.ValidationError(
+                {'impressions_one_time': 'If booking type is fixed, impressions_one_time is required'})
+        if data.get('booking_type') == BOOKING_TYPE_CONTINUOUS and not data.get('impressions_per_month'):
+            raise serializers.ValidationError(
+                {'impressions_per_month': 'If booking type is continuous, impressions_per_month is required'})
+
+        return data
+
 
 class OrderLineFacebookDetailedTargetingSerializer(serializers.Serializer):
     """
@@ -2078,11 +2047,6 @@ class OrderLineSerializer(serializers.Serializer):
     """
     payment_cycle = serializers.ChoiceField(choices=PRODUCT_PAYMENT_CYCLE_CHOICES, required=False)
 
-    """
-    sub-serializer for google ads basic specific product data ("google_basic" product subtype)
-    one detail dataset per order item, can be skipped if this detail is not meant for the item's product type
-    """
-    detail_google_ads_basic = OrderLineGoogleAdsBasicSerializer(required=False)
     """
     sub-serializer for google ads premium specific product data
     one detail dataset per order item, can be skipped if this detail is not meant for the item's product type
@@ -2324,7 +2288,7 @@ class Serializer(serializers.Serializer):
 
     def validate_productdetail_exists(self, data):
         mapping = {
-            PRODUCT_TYPE_GOOGLE_ADS: {'detail_google_ads_basic', 'detail_google_ads_premium'},
+            PRODUCT_TYPE_GOOGLE_ADS: {'detail_google_ads_premium'},
             PRODUCT_TYPE_DISPLAY: {'detail_display_basic', 'detail_display_premium'},
             PRODUCT_TYPE_FACEBOOK: {'detail_facebook'},
             PRODUCT_TYPE_IN_APP: {'detail_inapp'},
